diff -Naur -x episode modules.orig/tv/schedules.php modules/tv/schedules.php
--- modules.orig/tv/schedules.php	2013-09-15 19:11:23.000000000 -0700
+++ modules/tv/schedules.php	2014-09-18 13:29:12.466134864 -0700
@@ -36,9 +36,9 @@
             $schedule->profile  = '';
             $schedule->recgroup = '';
         }
-    // Add a blank channel, to suppress warnings
-        if (!$schedule->channel) {
-            $schedule->channel = Channel::find(null);
+    // Add a blank channel, to suppress warnings, or for "Any" channel schedules without "This Channel" filter
+        if (!$schedule->channel || ($schedule->type == rectype_daily || $schedule->type == rectype_always || $schedule->type == rectype_weekly || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
+            $schedule->channel =& Channel::find(null);
         }
     // Add this show
         $the_schedules[] = &$schedule;
diff -Naur -x episode modules.orig/tv/tmpl/default/schedules.php modules/tv/tmpl/default/schedules.php
--- modules.orig/tv/tmpl/default/schedules.php	2014-09-18 13:29:54.400413771 -0700
+++ modules/tv/tmpl/default/schedules.php	2014-09-18 13:06:14.704940371 -0700
@@ -95,8 +95,8 @@
             $urlstr = 'recordid='.$schedule->recordid;
 
             $css_class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
-        // If this is an 'always on any channel' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
-            if (($schedule->type == rectype_always || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
+        // If this is a 'daily' or 'always on any channel' or 'weekly' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
+            if (($schedule->type == rectype_daily || $schedule->type == rectype_always || $schedule->type == rectype_weekly || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
                 $schedule->channel->name = '[ '.t('Any').' ]';
                 $schedule->channel->channum = 0;
             }
diff -Naur -x episode modules.orig/tv/tmpl/lite/schedules.php modules/tv/tmpl/lite/schedules.php
--- modules.orig/tv/tmpl/lite/schedules.php	2014-09-18 13:32:21.736865080 -0700
+++ modules/tv/tmpl/lite/schedules.php	2014-09-18 13:08:09.906574076 -0700
@@ -53,8 +53,8 @@
             $urlstr = 'recordid='.$schedule->recordid;
 
             $css_class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
-        // If this is an 'always on any channel' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
-            if (($schedule->type == rectype_always || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
+        // If this is a 'daily', 'always on any channel', 'weekly' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
+            if (($schedule->type == rectype_daily || $schedule->type == rectype_always || $schedule->type == rectype_weekly || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
                 $schedule->channel->name = '[ '.t('Any').' ]';
                 $schedule->channel->channum = 0;
             }
 
